@@ -1,15 +1,25 @@
 def base_data(folderName):
-    # app.py
+    # main.py
     app_tring = """from typing import Optional
 
 from fastapi import FastAPI
+from fastapi.middleware.cors import CORSMiddleware
 from controllers.tasks.tasks_controller import tasks
 
 app = FastAPI()
 # tasks
 app.include_router(tasks)
+
+# cors
+app.add_middleware(
+    CORSMiddleware,
+    allow_origins=["*"],
+    allow_credentials=True,
+    allow_methods=["*"],
+    allow_headers=["*"],
+)
     """
-    f = open(folderName + "/app.py", "a")
+    f = open(folderName + "/main.py", "a")
 
     f.write(app_tring)
     f.close()
@@ -282,11 +292,11 @@ def delete_{moduleName}_repository(id):
     f.write(repository_tring)
     f.close()
 
-# add modle to app.py
+# add modle to main.py
 
 
 def base_data_app(moduleName):
-    with open('app.py', 'r+') as f:
+    with open('main.py', 'r+') as f:
         lines = f.readlines()
         for i, line in enumerate(lines):
             # router
